@@ -94,11 +94,7 @@ GtkWidget *scrolledWindow = NULL;
 
 GtkTreeViewColumn *column1 = NULL;
 
-#if GTK_MAJOR_VERSION>=3
 GtkWidget *recentGrid = NULL;
-#else
-GtkWidget *recentVbox=NULL;
-#endif
 
 GtkWidget *recentHbox = NULL;
 
@@ -120,16 +116,8 @@ gboolean setup_gui(GError **err)
 	//GtkAccelGroup* accelgroup = NULL;
 	GError *tempErr = NULL;
 
-#if GTK_MAJOR_VERSION >= 3
 	GtkWidget *grid;
 	GtkWidget *fullGrid = NULL;
-#else
-	GtkWidget *vbox=NULL;
-	GtkWidget *hbox=NULL;
-
-	GtkWidget *statusBarVbox=NULL;
-	GtkWidget *fullVbox=NULL;
-#endif
 
 	GtkWidget *recentScrolledWindow = NULL;
 
@@ -167,115 +155,16 @@ gboolean setup_gui(GError **err)
 
 	// Main content of the window is a vpaned
 
-#if GTK_MAJOR_VERSION>=3
 	vpaned = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
 
 	// Then we need a grid
 	grid = gtk_grid_new();
 
-#else
-	vpaned=gtk_vpaned_new();
-
-	// Then we need a vbox
-
-	if (!(vbox = gtk_vbox_new(FALSE, 0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_vbox_new() = NULL",
-		            __func__,
-		            "Couldn't init main vbox"
-		           );
-		goto EXITPOINT;
-	}
-
-	//gtk_container_add(GTK_CONTAINER(sMainWindow), vbox);
-
-#endif
-
-
-	// Create menus
-
-	/*
-	if (!(sActionGroup = gtk_action_group_new("SciteProjActions"))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_action_group_new() = NULL",
-			__func__,
-			"Couldn't init gtk_action_group"
-		);
-
-		goto EXITPOINT;
-	}
-	*/
-
-	/*
-	if (!(sGtkUIManager = gtk_ui_manager_new())) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_ui_manager_new() = NULL",
-			__func__,
-			"Couldn't init gtk_ui_manager"
-		);
-
-		goto EXITPOINT;
-	}
-	*/
-
-
-
-#if GTK_MAJOR_VERSION >= 3
-	//g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), grid);
-#else
-	//g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), vpaned);
-	// g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), vbox);
-#endif
-
-	// Fix the context-based translations for the menu strings
-	/*
-	int co=0;
-	gchar *temp=NULL;
-	gchar *context=NULL;
-	do {
-		context=menustrings[co].context;
-		if (context!=NULL) {
-			temp = (gchar*)g_dpgettext2(PACKAGE,menustrings[co].context,menustrings[co].string);
-
-			if (temp!=NULL) {
-				sMenuActions[co].label = g_strdup_printf("%s",temp);
-				++co;
-			}
-		}
-	} while (context!=NULL);
-	*/
-
-	/*
-		gtk_action_group_set_translation_domain(sActionGroup,PACKAGE);
-
-		gtk_action_group_add_actions(sActionGroup, sMenuActions, sNumMenuActions, NULL);
-
-		gtk_ui_manager_insert_action_group(sGtkUIManager, sActionGroup, 0);
-
-		if (gtk_ui_manager_add_ui_from_string(sGtkUIManager, sMenuDefXML, strlen(sMenuDefXML), &tempErr) == 0) {
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_ui_manager_add_ui_from_string() = %s",
-				__func__,
-				"Couldn't init menus from XML",
-				tempErr->message
-			);
-
-			goto EXITPOINT;
-		}
-
-		gtk_ui_manager_ensure_update(sGtkUIManager);
-	*/
 	// Activate the keyboard accelerators
 
 	accelerator_group = gtk_accel_group_new();
 	gtk_window_add_accel_group(GTK_WINDOW(sMainWindow), accelerator_group);
 
-	/*
-		// Create popup menus (shown when user right-clicks in gui elements)
-
-		sGeneralPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GeneralPopup");
-		sGroupPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GroupPopup");
-
-		//sFilePopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/FilePopup");
-	*/
-	//sFilePopupMenu = gtk_menu_new();
-
 	if (init_menus(sMainWindow)!=0) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_scrolled_window_new() = NULL",
 		            __func__,
@@ -284,14 +173,7 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 
-	/*
-		recentPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/RecentPopup");
-
-		sSortPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/SortPopup");
-	*/
-
 	// Add a scrolled window to the main window
-
 	if (!(scrolledWindow = gtk_scrolled_window_new(NULL, NULL))) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s, gtk_scrolled_window_new() = NULL",
 		            __func__,
@@ -304,20 +186,10 @@ gboolean setup_gui(GError **err)
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow),
 	                               GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
-#if GTK_MAJOR_VERSION>=3
 	gtk_grid_attach(GTK_GRID(grid), scrolledWindow, 0, 1, 1, 1);
 
 	gtk_widget_set_vexpand(scrolledWindow, TRUE);
 	gtk_widget_set_hexpand(scrolledWindow, TRUE);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), scrolledWindow, TRUE, TRUE, 0);
-
-	hbox=gtk_hbox_new(FALSE,0);
-
-	gtk_widget_show(hbox);
-
-	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,TRUE,0);
-#endif
 
 	// Create the tree datastore
 
@@ -340,8 +212,6 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 
-	//g_object_unref(G_OBJECT(projectTreeStore));
-
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(projectTreeView), TRUE);
 
 	if (!(textCellRenderer = gtk_cell_renderer_text_new())) {
@@ -393,8 +263,6 @@ gboolean setup_gui(GError **err)
 	gtk_tree_view_column_add_attribute(column1, textCellRenderer, "weight", COLUMN_FONTWEIGHT);
 	gtk_tree_view_column_add_attribute(column1, textCellRenderer, "weight-set", COLUMN_FONTWEIGHTSET);
 
-	//g_signal_connect(G_OBJECT(textCellRenderer), "edited", G_CALLBACK(rename_cb), NULL);
-
 	gtk_tree_view_append_column(GTK_TREE_VIEW(projectTreeView), column1);
 
 	// Stoopid gtk always expands the last column
@@ -428,8 +296,6 @@ gboolean setup_gui(GError **err)
 	// --------------------------------
 	// Recent file stuff:
 
-#if GTK_MAJOR_VERSION>=3
-
 	if (!(recentGrid = gtk_grid_new())) {
 		g_set_error(err, APP_SCITEPROJ_ERROR,-1,
 		            "%s: %s, gtk_grid_new() = NULL",
@@ -438,37 +304,12 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 
-#else
-	if (!(recentVbox=gtk_vbox_new(FALSE, 0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR,-1,
-		            "%s: %s, gtk_vbox_new() = NULL",
-		            __func__,
-		            "Couldn't init recent grid"
-		           );
-		goto EXITPOINT;
-	}
-#endif
-
-#if GTK_MAJOR_VERSION>=3
-	if (!(recentHbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0))) {
-#else
-	if (!(recentHbox=gtk_hbox_new(FALSE,0))) {
-#endif
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
-		            "%s: %s, gtk_hbox_new() = NULL",
-		            __func__,
-		            "Couldn't init main vbox"
-		           );
-		goto EXITPOINT;
-	}
-
 	if ((recentScrolledWindow = init_recent_files(&tempErr)) == NULL) {
 
 		goto EXITPOINT;
 	}
 
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_widget_set_vexpand(recentScrolledWindow, TRUE);
 	gtk_widget_set_hexpand(recentScrolledWindow, TRUE);
 
@@ -476,48 +317,14 @@ gboolean setup_gui(GError **err)
 
 	fullGrid = gtk_grid_new();
 
-#else
-
-	if (!(fullVbox=gtk_vbox_new(FALSE,0))) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
-		            "%s: %s, gtk_hbox_new() = NULL",
-		            __func__,
-		            "Couldn't init full_vbox"
-		           );
-
-		goto EXITPOINT;
-	}
-
-	gtk_box_pack_start(GTK_BOX(recentVbox),recentScrolledWindow, TRUE,TRUE,0);
-	gtk_box_pack_end(GTK_BOX(recentVbox),recentHbox,FALSE,TRUE,0);
 
 
-	statusBarVbox=gtk_vbox_new(FALSE,0);
-
-	if (!statusBarVbox) {
-		g_set_error(err, APP_SCITEPROJ_ERROR, -1,
-		            "%s: %s, gtk_hbox_new() = NULL",
-		            __func__,
-		            "Couldn't init statusbar_vbox"
-		           );
-		goto EXITPOINT;
-	}
-#endif
-
-
-#if GTK_MAJOR_VERSION >= 3
 	gtk_paned_pack1(GTK_PANED(vpaned), grid, TRUE, FALSE);
 	gtk_paned_pack2(GTK_PANED(vpaned), recentGrid, TRUE, TRUE);
-#else
-	gtk_paned_pack1(GTK_PANED(vpaned),vbox,TRUE,FALSE);
-	gtk_paned_pack2(GTK_PANED(vpaned),recentVbox,TRUE,TRUE);
-#endif
 
 	gtk_widget_show(vpaned);
 
 
-#if GTK_MAJOR_VERSION >= 3
-
 
 	gtk_grid_insert_row(GTK_GRID(fullGrid), 0);
 	gtk_grid_attach(GTK_GRID(fullGrid), vpaned, 0, 0, 1, 1);
@@ -539,32 +346,6 @@ gboolean setup_gui(GError **err)
 	gtk_container_add(GTK_CONTAINER(sMainWindow), fullGrid);
 
 
-#else
-
-	gtk_box_pack_start(GTK_BOX(fullVbox),menuBar, FALSE, FALSE, 0);
-
-	gtk_widget_show(menuBar);
-	gtk_box_pack_start(GTK_BOX(fullVbox),vpaned,TRUE,TRUE,0);
-
-	gtk_widget_show(GTK_WIDGET(fullVbox));
-
-
-	if (!prefs.hide_statusbar) {
-		if (!init_statusbar(fullVbox,vpaned,&tempErr)) {
-			g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: %s",
-			            tempErr->message,
-			            "Couldn't init statusbar"
-			           );
-			goto EXITPOINT;
-		}
-	}
-
-	gtk_container_add(GTK_CONTAINER(sMainWindow), fullVbox);
-
-	gtk_widget_show(fullVbox);
-	gtk_widget_show(vpaned);
-
-#endif
 	g_signal_connect(G_OBJECT(recentTreeView), "key-press-event", G_CALLBACK(key_press_cb), recentTreeView);
 
 	gtk_window_resize(GTK_WINDOW(sMainWindow), prefs.width, prefs.height);
@@ -577,7 +358,6 @@ gboolean setup_gui(GError **err)
 
 	// Show it all....
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_widget_show(recentGrid);
 
 	if (!prefs.show_recent) {
@@ -585,23 +365,10 @@ gboolean setup_gui(GError **err)
 	} else {
 		gtk_widget_show(recentGrid);
 	}
-#else
-	gtk_widget_show(recentVbox);
-
-	if (!prefs.show_recent) {
-		gtk_widget_hide(recentVbox);
-	} else {
-		gtk_widget_show(recentVbox);
-	}
-#endif
 
 	gtk_widget_show(projectTreeView);
 	gtk_widget_show(scrolledWindow);
-#if GTK_MAJOR_VERSION >= 3
 	gtk_widget_show(grid);
-#else
-	gtk_widget_show(vbox);
-#endif
 	gtk_widget_show(sMainWindow);
 
 	resultCode = TRUE;
@@ -837,17 +604,9 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	                                   &path, NULL, NULL, NULL)) {
 		// Nope-- user clicked in the GtkTreeView, but not on a node
 
-#if ((GTK_MAJOR_VERSION >= 3) && (GTK_MINOR_VERSION >= 22))
 		if (generalPopupMenu) {
 			gtk_menu_popup_at_pointer(GTK_MENU(generalPopupMenu), (GdkEvent*)event);													
 		}
-#else
-		if (generalPopupMenu) {
-			gtk_menu_popup(GTK_MENU(generalPopupMenu),
-		               NULL, NULL, NULL, NULL,
-		               event->button, gdk_event_get_time((GdkEvent*) event));
-		}
-#endif
 													  
 		goto EXITPOINT;
 	}
@@ -891,32 +650,17 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	// Pop up the appropriate menu for the node type
 
 	if (nodeItemType == ITEMTYPE_FILE) {
-#if ((GTK_MAJOR_VERSION >= 3) && (GTK_MINOR_VERSION >= 22))
 		if (fileRightClickPopupMenu) {
 			gtk_menu_popup_at_pointer(GTK_MENU(fileRightClickPopupMenu), (GdkEvent*)event);
 		}
-#else
-		if (fileRightClickPopupMenu) {
-			gtk_menu_popup(GTK_MENU(fileRightClickPopupMenu), NULL, NULL, NULL, NULL,
-						event->button, gdk_event_get_time((GdkEvent*) event));
-		}
-#endif
 	}
 	else if (nodeItemType == ITEMTYPE_GROUP) {
-#if ((GTK_MAJOR_VERSION >= 3) && (GTK_MINOR_VERSION >= 22))
 		if (groupRightClickPopupMenu) {
 			gtk_menu_popup_at_pointer(GTK_MENU(groupRightClickPopupMenu), (GdkEvent*)event);
 		}
-#else
-		if (groupRightClickPopupMenu) {
-			gtk_menu_popup(GTK_MENU(groupRightClickPopupMenu), NULL, NULL, NULL, NULL,
-		               event->button, gdk_event_get_time((GdkEvent*) event));
-		}
-#endif
 	}
 
-	// We took care of the event, so no need to propogate it
-
+	
 	eventHandled = TRUE;
 
 
@@ -976,7 +720,6 @@ void recent_files_switch_visible()
 {
 	gboolean visible = FALSE;
 
-#if GTK_MAJOR_VERSION >= 3
 	g_object_get(G_OBJECT(recentGrid), "visible", &visible, NULL);
 
 	if (visible) {
@@ -985,16 +728,6 @@ void recent_files_switch_visible()
 	} else {
 		gtk_widget_show(recentGrid);
 	}
-#else
-	g_object_get(G_OBJECT(recentVbox),"visible", &visible,NULL);
-
-	if (visible) {
-		gtk_widget_hide(recentVbox);
-		gtk_widget_grab_focus(projectTreeView);
-	} else {
-		gtk_widget_show(recentVbox);
-	}
-#endif
 
 }
 
